pub trait MaybeHash: Hash { }Expand description
Type which implements Hash in std, not when no-std (std variant).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait MaybeHash: Hash { }Type which implements Hash in std, not when no-std (std variant).
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".