pub trait AppCrypto:
'static
+ Sized
+ CryptoType {
type Public: AppPublic;
type Signature: AppSignature;
type ProofOfPossession: AppSignature;
type Pair: AppPair;
const ID: KeyTypeId;
const CRYPTO_ID: CryptoTypeId;
}Expand description
Application-specific cryptographic object.
Combines all the core types and constants that are defined by a particular cryptographic scheme when it is used in a specific application domain.
Typically, the implementers of this trait are its associated types themselves. This provides a convenient way to access generic information about the scheme given any of the associated types.
Required Associated Constants
Sourceconst CRYPTO_ID: CryptoTypeId
const CRYPTO_ID: CryptoTypeId
Identifier of the crypto type of this application-specific key type.
Required Associated Types
Sourcetype Signature: AppSignature
type Signature: AppSignature
The corresponding signature type in this application scheme.
Sourcetype ProofOfPossession: AppSignature
type ProofOfPossession: AppSignature
The corresponding proof of possession type in this application scheme.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".